API docs for “spamfighter.core.partner”

# Module s.c.partner

Part of spamfighter.core View Source

Базовые классы и методы работы с партнерами.

Class | PartnerAuthorizationFailedError | Авторизация партнера была неуспешной.
Function | getPartnerAuthorizer | Получить текущий механизм авторизации партнеров.
Function | getPartnerAuthorizerProvider | Получить провайдер авторизации партнеров.

def getPartnerAuthorizer(): (source)
Получить текущий механизм авторизации партнеров.

Returns | механизм авторизации партнеров (type: `spamfighter.interfaces.IPartnerAuthorizer` )

def getPartnerAuthorizerProvider(): (source)
Получить провайдер авторизации партнеров.

Загружаем как плагин, предсоставляющий интерфейс `IPartnerAuthorizerProvider` с именем из конфига: config.plugins.partner.default_provider

Returns | провайдер авторизации партнеров (type: `IPartnerAuthorizerProvider` )